"""Stream output of main.py script to index.html"""
# import matplotlib
# matplotlib.use('tkagg')
import threading
import cv2
from flask import Flask, render_template, Response
from tools import plot_detection, Main

app = Flask(__name__)
sm = threading.Semaphore(10)
main = Main(sm)
main.start_thread()

@app.route('/')
def index():
    """
    Run html script.
    """
    return render_template('index.html', decode_responses=True)


def gen():
    """
    Acquire image from shared memory, plot on it the positions of the detected ions and
    return it.
    """
    while True:
        sm.acquire()
        image = main.output['image'].copy()
        coord = main.output['coord'].copy()
        sm.release()
        image = plot_detection(image, coord.astype(int))
        frame = cv2.imencode(".jpg", image)[1].tobytes()
        yield (b'--frame\r\n'
               b'Content-Type: image/jpeg\r\n\r\n' + frame + b'\r\n')


@app.route('/stream')
def video_feed():
    """
    Stream the image returned from gen().
    """
    return Response(gen(), mimetype='multipart/x-mixed-replace; boundary=frame')


@app.route('/stream_text')
def ion_number():
    """
    Stream the values obtained from processing.
    """
    att = main.output.copy()
    try:
        del att['image']
        del att['coord']
    except KeyError:
        pass
    return att


if __name__ == '__main__':
    app.run(debug=False, host='0.0.0.0')
