"""Calibrate the trap by calculating the distance factor."""
import numpy as np
import pandas as pd
import redis
from tools import load_image, ion_positions, dark_ions, read_factor

def main():
    """ Main function """
    conn = redis.Redis('localhost', decode_responses=True)

    image = load_image()
    pos, _ = ion_positions(image)
    user_2 = input("Use (detected) dark ions for calibration? (y, [n])   ")
    if user_2 in ("y", "yes"):
        dist_factor = read_factor(conn)
        pos = dark_ions(image, pos, dist_factor)
    pos = pos[:, 1]

    if len(pos) > 1:
        print('The detected ions are at positions: ', pos)

        pos = pos[pos.argsort()] # order
        pos = (pos - pos[0])[1:]
        mask = (pd.read_csv('data/mask.csv', index_col=0).to_numpy())[len(pos) - 1][1:len(pos)+1]

        new_dist_factor = round(np.mean(pos/mask), 1)

        conn.set(name='/image_analysis/distance_factor', value=new_dist_factor)

        print('The factor is {}'.format(new_dist_factor))
    else:
        print('The trap needs to have more than 1 ion to calibrate.')


if __name__ == "__main__":
    main()
